@@ -31,8 +31,8 @@ module.exports = {
   appIndexJs: resolveApp('src/index.js'),
   appPackageJson: resolveApp('package.json'),
   appSrc: resolveApp('src'),
-  testsSetup: resolveApp('src/setupTests.js'),
   appNodeModules: resolveApp('node_modules'),
+  appVersionJs: resolveApp('src/version.js'),
   ownNodeModules: resolveApp('node_modules'),
   nodePaths: nodePaths,
 }
