@@ -2,7 +2,7 @@ import React from 'react'
 import PropTypes from 'prop-types'
 import { Link } from 'react-router-dom'
 import { connect } from 'react-redux'
-import { msg } from '../../intl'
+import { msg } from '_/intl'
 
 const buildPath = (vms, branches) => {
   const res = []
