@@ -7,9 +7,9 @@ import { Notification, NotificationDrawer, MenuItem, Icon, Button } from 'patter
 
 import style from './style.css'
 
-import { clearUserMessages, dismissUserMessage } from '../../actions'
-import { hrefWithoutHistory, getFormatedDateTime } from '../../helpers'
-import { msg } from '../../intl'
+import { clearUserMessages, dismissUserMessage } from '_/actions'
+import { hrefWithoutHistory, getFormatedDateTime } from '_/helpers'
+import { msg } from '_/intl'
 
 const UserMessage = ({ record, id, onDismissMessage }) => {
   const time = getFormatedDateTime(record.get('time'))
@@ -63,7 +63,8 @@ class VmUserMessages extends React.Component {
       ? userMessages.get('records').map(r => (
         <UserMessage
           key={`msg-${r.get('time')}`}
-          record={r} id={`${idPrefix}-msg-${r.get('time')}-dropdown`}
+          record={r}
+          id={`${idPrefix}-msg-${r.get('time')}-dropdown`}
           onDismissMessage={() => onDismissMessage(r.get('time'))}
         />
       ))
@@ -75,7 +76,7 @@ class VmUserMessages extends React.Component {
     return (
       <li className='dropdown'>
         <a className='dropdown-toggle nav-item-iconic' href='#' title={msg.messages()} onClick={hrefWithoutHistory(this.handleToggle)} id={`${idPrefix}-toggle`}>
-          <i className='fa fa-bell' />
+          <i className={`fa fa-bell ${style['usermessages-icon']}`} />
           {badgeElement}
           <span className='caret' id={`${idPrefix}-caret`} />
         </a>
@@ -83,14 +84,16 @@ class VmUserMessages extends React.Component {
           <NotificationDrawer.Title onCloseClick={this.handleToggle} onExpandClick={this.handleExpand} />
           <NotificationDrawer.PanelBody className={style['panel-body']}>
             {messagesList}
-            <NotificationDrawer.PanelAction>
-              <NotificationDrawer.PanelActionLink data-toggle='clear-all'>
-                <Button bsStyle='link' onClick={onClearMessages} disabled={!messagesCount}>
-                  <Icon type='pf' name='close' />
-                  { msg.clearAll() }
-                </Button>
-              </NotificationDrawer.PanelActionLink>
-            </NotificationDrawer.PanelAction>
+            { messagesCount > 0 &&
+              <NotificationDrawer.PanelAction>
+                <NotificationDrawer.PanelActionLink data-toggle='clear-all'>
+                  <Button bsStyle='link' onClick={onClearMessages}>
+                    <Icon type='pf' name='close' />
+                    { msg.clearAll() }
+                  </Button>
+                </NotificationDrawer.PanelActionLink>
+              </NotificationDrawer.PanelAction>
+            }
           </NotificationDrawer.PanelBody>
         </NotificationDrawer>
       </li>
