@@ -44,9 +44,10 @@ export const messages: { [messageId: string]: MessageType } = {
   bootSequence: 'Boot Sequence',
   bootSequenceTooltip: 'Device order in which VM will search OS for running.',
   cancel: 'Cancel',
-  cantLogonToConsole: 'SSO logon to the VM\'s console failed. Do you want to continue without SSO?',
+  cannotUpdateCloudInitHostname: 'Host name cannot be synchronized with VM name because the VM name is not a valid host name.',
+  cantLogonToConsole: 'Single sign on failed. Please check to see if the guest agent is running on your virtual machine. Contact your administrator if the problem continues.',
   cardTitleDetails: 'Details',
-  cardTooltipEditDetails: 'Edit details for {vmId}',
+  cardTooltipEditDetails: 'Edit details for {vmName}',
   cd: 'CD',
   cdCanOnlyChangeWhenVmRunning: 'CD can only be changed when the VM is running',
   cdromBoot: 'CD-ROM',
@@ -65,6 +66,10 @@ export const messages: { [messageId: string]: MessageType } = {
   clusterCanOnlyChangeWhenVmStopped: 'Cluster can only be changed when the VM is stopped.',
   confirmDelete: 'Confirm Delete',
   confirmRestore: 'Confirm Restore',
+  connect: {
+    message: 'Connect',
+    description: 'Connect button for SSO authorization modal dialog.',
+  },
   connectAutomatically: 'Connect automatically',
   console: 'Console',
   consoleInUseContinue: 'Console in use, continue?',
@@ -120,9 +125,10 @@ export const messages: { [messageId: string]: MessageType } = {
   diskStateInactiveTooltip: 'Inactive',
   diskStateLockedTooltip: 'Locked',
   disks: 'Disks',
-  disksCardEditTooltip: 'Edit Disks for {vmId}',
+  disksCardEditTooltip: 'Edit Disks for {vmName}',
   diskSizeHasToBeAPositiveInteger: 'Disk size has to be a positive integer.',
   displayAll: 'Display all',
+  updateCloudInit: 'Do you want update Cloud-init hostname on new VM name?',
   edit: 'Edit',
   editDisk: 'Edit Disk',
   editNic: 'Edit NIC',
@@ -305,7 +311,7 @@ export const messages: { [messageId: string]: MessageType } = {
   nextSnapshotsWillBeDeleted: 'Restoring this snapshot will also delete newer snapshots:',
   nic: 'Network interfaces',
   nicActionCreateNew: 'Create NIC',
-  nicCardEditTooltip: 'Edit NICs for {vmId}',
+  nicCardEditTooltip: 'Edit NICs for {vmName}',
   nicDeleteDisabledTooltip: 'Cannot delete the NIC at this time',
   nicDeleteTooltip: 'Delete',
   nicEditDisabledTooltip: 'Cannot edit the NIC at this time',
@@ -358,7 +364,7 @@ export const messages: { [messageId: string]: MessageType } = {
   permissionsNoEditVm: 'You do not have the required permissions to edit a VM.',
   permissionsNoEditThisVm: 'You do not have permissions to edit VM {name} / {vmId}',
   pendingChanges: 'Pending Changes',
-  pleaseEnterValidVmName: 'Please enter valid virtual machine name. Only lower-case and upper-case letters, numbers, \'_\', \'-\', \'.\' are allowed.',
+  pleaseEnterValidVmName: 'Please enter a valid virtual machine name. Only lower-case and upper-case letters, numbers, and \'_\',\'-\',\'.\' are allowed.',
   pleaseLogIn: 'Please log in',
   pleaseLogInTripleDot: 'Please log in ...',
   preserveDisks: 'Preserve disks',
@@ -439,10 +445,47 @@ export const messages: { [messageId: string]: MessageType } = {
   upload: 'Upload',
   uploadIconFilesizeTooLarge: 'Image size should be {maxIconSize} KiB or less.',
   uploadIconNotImage: 'Icon should be an image.',
+  utilization: { message: 'Utilization', description: 'Title of Utilization card on VM Details' },
+  utilizationCardAllocated: 'Allocated',
+  utilizationCardAvailable: 'Available',
+  utilizationCardDiskUsed: {
+    message: '<strong>{used} of {total} {storageUnits}</strong> Used',
+    description: 'Used amount of a single file system on a VM (HTML may be embedded to emphasize the amounts',
+  },
+  utilizationCardOf: {
+    message: 'of {number} {storageUnits}',
+    description: 'example: "of 3.2 GiB"',
+  },
+  utilizationCardOf100: 'of 100%',
+  utilizationCardOfProvisioned: {
+    message: 'of {number} {storageUnits} Provisioned',
+    description: 'example: "of 1.2 GiB Provisioned"',
+  },
+  utilizationCardLegendAvailable: 'Available',
+  utilizationCardLegendAvailableP: '% Available',
+  utilizationCardLegendUsed: 'Used',
+  utilizationCardLegendUsedP: '% Used',
+  utilizationCardNoGuestAgent: 'It looks like no guest agent is configured on the VM.',
+  utilizationCardNoAttachedDisks: 'It looks like no disk is attached to VM.',
+  utilizationCardTitleCpu: 'CPU',
+  utilizationCardTitleDisk: 'Disk',
+  utilizationCardTitleMemory: 'Memory',
+  utilizationCardTitleNetworking: 'Networking',
+  utilizationCardUnallocated: 'Unallocated',
+  utilizationCardUnitAllocated: '{storageUnit} Allocated',
+  utilizationCardUnitNumber: {
+    message: '{number} {storageUnits}',
+    description: 'example: "4.2 TiB"',
+  },
+  utilizationCardUnitUsed: '{storageUnit} Used',
+  utilizationNoDataAvailableTitle: 'No Data Available',
+  utilizationNoDataAvailableMessage: 'Utilization data is only available when the VM is running.',
+  utilizationNoHistoricData: 'No historic data available',
+  utilizationNoNetStats: 'Network utilization is not currently available for this VM.',
   useBrowserBelow: 'Please use one of the browsers below.',
   useCtrlAltEnd: 'Use Ctrl+Alt+End',
   virtualMachines: 'Virtual Machines',
-  vmHasPendingConfigurationChanges: 'The virtual machine has pending configuration changes. To take effect, please reboot the virtual machine.',
+  vmHasPendingConfigurationChanges: 'This VM has pending configurations changes that will be applied once the VM is shutdown (or rebooted).',
   vmMemory: 'VM Memory',
   vmPortal: 'VM Portal',
   vmType_desktop: 'Desktop',
